@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: tasty-quickcheck
 version: 0.8.4
-id: tasty-quickcheck-0.8.4-be8b412a2fbf5b37aca9e2070c9110c1
-key: tasty_8YGWsrHIQGJDHLyJ2382ks
+id: tasty-quickcheck-0.8.4-e5a707480b8380bb1c505ef91cf9fe68
+key: tasty_JnFv8gOMGC3EpUYwhwezgA
 license: MIT
 maintainer: Roman Cheplyaka <roma@ro-che.info>
 homepage: http://documentup.com/feuerbach/tasty
@@ -19,12 +19,12 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/tasty-quickcheck-0.8.4
 library-dirs: /usr/lib/ghc-7.10.3/site-local/tasty-quickcheck-0.8.4
 data-dir: /usr/share/arm-linux-ghc-7.10.3/tasty-quickcheck-0.8.4
-hs-libraries: HStasty-quickcheck-0.8.4-8YGWsrHIQGJDHLyJ2382ks
+hs-libraries: HStasty-quickcheck-0.8.4-JnFv8gOMGC3EpUYwhwezgA
 depends:
     QuickCheck-2.8.2-7d8390b8c258848854e348a0ea775aaf
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
-    tasty-0.11.0.2-6ecf5c4c4584053c63756484aea2d9b8
+    tagged-0.8.4-af2e23230031c45949e0062e776a8f1f
+    tasty-0.11.0.3-0d04c7a0c25a1cdf39b68aca17d97b9d
 haddock-interfaces: /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock
 haddock-html: /usr/share/doc/haskell-tasty-quickcheck/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
